summaryrefslogtreecommitdiffstats
path: root/core
diff options
context:
space:
mode:
authorwm4 <wm4@nowhere>2012-11-09 01:06:43 +0100
committerwm4 <wm4@nowhere>2012-11-12 20:08:18 +0100
commit4873b32c5959c988af1769529ff72e3fd62fba82 (patch)
treee18fbd7eef54de6071969689aa5c31d6ea1f0963 /core
parentd4bdd0473d6f43132257c9fb3848d829755167a3 (diff)
downloadmpv-4873b32c5959c988af1769529ff72e3fd62fba82.tar.bz2
mpv-4873b32c5959c988af1769529ff72e3fd62fba82.tar.xz
Rename directories, move files (step 2 of 2)
Finish renaming directories and moving files. Adjust all include statements to make the previous commit compile. The two commits are separate, because git is bad at tracking renames and content changes at the same time. Also take this as an opportunity to remove the separation between "common" and "mplayer" sources in the Makefile. ("common" used to be shared between mplayer and mencoder.)
Diffstat (limited to 'core')
-rw-r--r--core/asxparser.c4
-rw-r--r--core/av_log.c2
-rw-r--r--core/bstr.c2
-rw-r--r--core/cfg-mplayer.h12
-rw-r--r--core/codec-cfg.c8
-rw-r--r--core/command.c31
-rw-r--r--core/cpudetect.c6
-rw-r--r--core/cpudetect.h2
-rw-r--r--core/defaultopts.c4
-rw-r--r--core/encode_lavc.c8
-rw-r--r--core/encode_lavc.h2
-rw-r--r--core/input/appleir.c2
-rw-r--r--core/input/input.c16
-rw-r--r--core/input/input.h6
-rw-r--r--core/input/joystick.c2
-rw-r--r--core/input/lirc.c2
-rw-r--r--core/m_config.c4
-rw-r--r--core/m_config.h2
-rw-r--r--core/m_option.c10
-rw-r--r--core/m_option.h2
-rw-r--r--core/m_property.c6
-rw-r--r--core/m_struct.c6
-rw-r--r--core/m_struct.h2
-rw-r--r--core/mp_common.c2
-rw-r--r--core/mp_core.h6
-rw-r--r--core/mp_fifo.c2
-rw-r--r--core/mp_fifo.h2
-rw-r--r--core/mp_msg.c2
-rw-r--r--core/mp_msg.h2
-rw-r--r--core/mplayer.c74
-rw-r--r--core/mplayer.h2
-rw-r--r--core/parser-cfg.c4
-rw-r--r--core/parser-mpcmd.c4
-rw-r--r--core/path.c4
-rw-r--r--core/path.h2
-rw-r--r--core/playlist.c4
-rw-r--r--core/playlist.h2
-rw-r--r--core/playlist_parser.c6
-rw-r--r--core/quvi.c4
-rw-r--r--core/screenshot.c24
-rw-r--r--core/subopt-helper.c4
-rw-r--r--core/timeline/tl_cue.c12
-rw-r--r--core/timeline/tl_edl.c12
-rw-r--r--core/timeline/tl_matroska.c12
44 files changed, 164 insertions, 163 deletions
diff --git a/core/asxparser.c b/core/asxparser.c
index 44236b8c18..17ce6b3e8c 100644
--- a/core/asxparser.c
+++ b/core/asxparser.c
@@ -27,9 +27,9 @@
#include "playlist.h"
#include "playlist_parser.h"
#include "stream/stream.h"
-#include "libmpdemux/demuxer.h"
+#include "demux/demux.h"
#include "asxparser.h"
-#include "mp_msg.h"
+#include "core/mp_msg.h"
typedef struct ASX_Parser_t ASX_Parser_t;
diff --git a/core/av_log.c b/core/av_log.c
index 4e27e98d0f..4a80488a4b 100644
--- a/core/av_log.c
+++ b/core/av_log.c
@@ -25,7 +25,7 @@
#include "av_log.h"
#include "config.h"
-#include "mp_msg.h"
+#include "core/mp_msg.h"
#include <libavutil/avutil.h>
#include <libavutil/log.h>
diff --git a/core/bstr.c b/core/bstr.c
index d3247ce1d6..5d8a47e9ac 100644
--- a/core/bstr.c
+++ b/core/bstr.c
@@ -25,7 +25,7 @@
#include "talloc.h"
-#include "bstr.h"
+#include "core/bstr.h"
int bstrcmp(struct bstr str1, struct bstr str2)
{
diff --git a/core/cfg-mplayer.h b/core/cfg-mplayer.h
index c0f4c91a9c..efb445cd68 100644
--- a/core/cfg-mplayer.h
+++ b/core/cfg-mplayer.h
@@ -26,13 +26,13 @@
#include <stddef.h>
#include <sys/types.h>
-#include "options.h"
+#include "core/options.h"
#include "config.h"
-#include "m_config.h"
-#include "m_option.h"
+#include "core/m_config.h"
+#include "core/m_option.h"
#include "stream/tv.h"
#include "stream/stream_radio.h"
-#include "libvo/csputils.h"
+#include "video/csputils.h"
extern char *lirc_configfile;
@@ -67,7 +67,7 @@ extern int reuse_socket;
extern int dvd_speed; /* stream/stream_dvd.c */
-/* defined in libmpdemux: */
+/* defined in demux: */
extern const m_option_t demux_rawaudio_opts[];
extern const m_option_t demux_rawvideo_opts[];
extern const m_option_t cdda_opts[];
@@ -204,7 +204,7 @@ const m_option_t mfopts_conf[]={
{NULL, NULL, 0, 0, 0, 0, NULL}
};
-#include "libaf/af.h"
+#include "audio/filter/af.h"
extern struct af_cfg af_cfg; // Audio filter configuration, defined in libmpcodecs/dec_audio.c
const m_option_t audio_filter_conf[]={
{"list", &af_cfg.list, CONF_TYPE_STRING_LIST, 0, 0, 0, NULL},
diff --git a/core/codec-cfg.c b/core/codec-cfg.c
index da4c64c4c0..c8fc3c74bb 100644
--- a/core/codec-cfg.c
+++ b/core/codec-cfg.c
@@ -31,12 +31,12 @@
#include <stdint.h>
#include "config.h"
-#include "mp_msg.h"
-#include "libmpcodecs/img_format.h"
+#include "core/mp_msg.h"
+#include "video/img_format.h"
#include "codec-cfg.h"
-#include "bstr.h"
+#include "core/bstr.h"
#include "stream/stream.h"
-#include "path.h"
+#include "core/path.h"
static const char embedded_file[] =
#include "codecs.conf.h"
diff --git a/core/command.c b/core/command.c
index 14f24ac50e..f333f20f54 100644
--- a/core/command.c
+++ b/core/command.c
@@ -28,32 +28,33 @@
#include "command.h"
#include "input/input.h"
#include "stream/stream.h"
-#include "libmpdemux/demuxer.h"
-#include "libmpdemux/stheader.h"
+#include "demux/demux.h"
+#include "demux/stheader.h"
#include "codec-cfg.h"
#include "mplayer.h"
#include "playlist.h"
#include "playlist_parser.h"
#include "sub/sub.h"
#include "sub/dec_sub.h"
-#include "m_option.h"
+#include "core/m_option.h"
#include "m_property.h"
#include "m_config.h"
-#include "libmpcodecs/vf.h"
-#include "libmpcodecs/vd.h"
+#include "video/filter/vf.h"
+#include "video/decode/vd.h"
#include "mp_osd.h"
-#include "libvo/video_out.h"
-#include "libvo/csputils.h"
+#include "video/out/vo.h"
+#include "video/csputils.h"
#include "playlist.h"
-#include "libao2/audio_out.h"
-#include "mpcommon.h"
-#include "mixer.h"
-#include "libmpcodecs/dec_video.h"
-#include "libmpcodecs/dec_audio.h"
+#include "audio/mixer.h"
+#include "audio/out/ao.h"
+#include "core/mp_common.h"
+#include "audio/filter/af.h"
+#include "video/decode/dec_video.h"
+#include "audio/decode/dec_audio.h"
#include "osdep/strsep.h"
#include "sub/vobsub.h"
#include "sub/spudec.h"
-#include "path.h"
+#include "core/path.h"
#include "sub/ass_mp.h"
#include "stream/tv.h"
#include "stream/stream_radio.h"
@@ -64,10 +65,10 @@
#ifdef CONFIG_DVDREAD
#include "stream/stream_dvd.h"
#endif
-#include "m_struct.h"
+#include "core/m_struct.h"
#include "screenshot.h"
-#include "mp_core.h"
+#include "core/mp_core.h"
#include "mp_fifo.h"
#include "libavutil/avstring.h"
diff --git a/core/cpudetect.c b/core/cpudetect.c
index 283600aff6..62cb03008d 100644
--- a/core/cpudetect.c
+++ b/core/cpudetect.c
@@ -21,11 +21,11 @@
#include <stdlib.h>
#include <libavutil/cpu.h>
-#include "libav_compat.h"
+#include "compat/libav.h"
#include "config.h"
-#include "cpudetect.h"
-#include "mp_msg.h"
+#include "core/cpudetect.h"
+#include "core/mp_msg.h"
CpuCaps gCpuCaps;
diff --git a/core/cpudetect.h b/core/cpudetect.h
index 675dcbacde..d3d9206c65 100644
--- a/core/cpudetect.h
+++ b/core/cpudetect.h
@@ -22,7 +22,7 @@
#include <stdbool.h>
#include "config.h"
-#include "ffmpeg_files/x86_cpu.h"
+#include "compat/x86_cpu.h"
typedef struct cpucaps_s {
bool hasMMX;
diff --git a/core/defaultopts.c b/core/defaultopts.c
index 1d3abf932c..a20656dd02 100644
--- a/core/defaultopts.c
+++ b/core/defaultopts.c
@@ -2,8 +2,8 @@
#include "config.h"
#include "defaultopts.h"
-#include "options.h"
-#include "mixer.h"
+#include "core/options.h"
+#include "audio/mixer.h"
void set_default_mplayer_options(struct MPOpts *opts)
{
diff --git a/core/encode_lavc.c b/core/encode_lavc.c
index 5812fe0fed..d35db70b4f 100644
--- a/core/encode_lavc.c
+++ b/core/encode_lavc.c
@@ -22,11 +22,11 @@
#include "encode_lavc.h"
-#include "mp_msg.h"
-#include "libmpcodecs/vfcap.h"
-#include "options.h"
+#include "core/mp_msg.h"
+#include "video/vfcap.h"
+#include "core/options.h"
#include "osdep/timer.h"
-#include "libvo/video_out.h"
+#include "video/out/vo.h"
#include "talloc.h"
#include "stream/stream.h"
diff --git a/core/encode_lavc.h b/core/encode_lavc.h
index 29b35c6335..747043b8b5 100644
--- a/core/encode_lavc.h
+++ b/core/encode_lavc.h
@@ -28,7 +28,7 @@
#include <libavutil/mathematics.h>
#include "encode.h"
-#include "libvo/csputils.h"
+#include "video/csputils.h"
struct encode_lavc_context {
struct encode_output_conf *options;
diff --git a/core/input/appleir.c b/core/input/appleir.c
index c64bc9648d..4615f1ef9d 100644
--- a/core/input/appleir.c
+++ b/core/input/appleir.c
@@ -37,7 +37,7 @@
#include <linux/types.h>
#include <linux/input.h>
-#include "mp_msg.h"
+#include "core/mp_msg.h"
// keycodes.h defines would conflict with linux/input.h ones
#define AR_DEFINES_ONLY
diff --git a/core/input/input.c b/core/input/input.c
index 6643747e4d..115d181e69 100644
--- a/core/input/input.c
+++ b/core/input/input.c
@@ -34,18 +34,18 @@
#include "osdep/io.h"
#include "input.h"
-#include "mp_fifo.h"
+#include "core/mp_fifo.h"
#include "keycodes.h"
#include "osdep/timer.h"
#include "libavutil/avstring.h"
#include "libavutil/common.h"
-#include "mp_msg.h"
-#include "m_config.h"
-#include "m_option.h"
-#include "path.h"
+#include "core/mp_msg.h"
+#include "core/m_config.h"
+#include "core/m_option.h"
+#include "core/path.h"
#include "talloc.h"
-#include "options.h"
-#include "bstr.h"
+#include "core/options.h"
+#include "core/bstr.h"
#include "stream/stream.h"
#include "joystick.h"
@@ -545,7 +545,7 @@ static const m_option_t mp_input_opts[] = {
static int default_cmd_func(int fd, char *buf, int l);
static const char builtin_input_conf[] =
-#include "input/input_conf.h"
+#include "core/input/input_conf.h"
;
// Encode the unicode codepoint as UTF-8, and append to the end of the
diff --git a/core/input/input.h b/core/input/input.h
index 59f2d031ff..a1c633ad69 100644
--- a/core/input/input.h
+++ b/core/input/input.h
@@ -20,8 +20,8 @@
#define MPLAYER_INPUT_H
#include <stdbool.h>
-#include "bstr.h"
-#include "m_option.h"
+#include "core/bstr.h"
+#include "core/m_option.h"
// All command IDs
enum mp_command_type {
@@ -211,7 +211,7 @@ void mp_input_register_options(struct m_config *cfg);
// Wake up sleeping input loop from another thread.
void mp_input_wakeup(struct input_ctx *ictx);
-// Interruptible usleep: (used by libmpdemux)
+// Interruptible usleep: (used by demux)
int mp_input_check_interrupt(struct input_ctx *ictx, int time);
extern int async_quit_request;
diff --git a/core/input/joystick.c b/core/input/joystick.c
index 673ae92184..ae2bf7990b 100644
--- a/core/input/joystick.c
+++ b/core/input/joystick.c
@@ -30,7 +30,7 @@
#include <fcntl.h>
#include <errno.h>
-#include "mp_msg.h"
+#include "core/mp_msg.h"
#include "keycodes.h"
#ifndef JOY_AXIS_DELTA
diff --git a/core/input/lirc.c b/core/input/lirc.c
index fd64beb479..699168d239 100644
--- a/core/input/lirc.c
+++ b/core/input/lirc.c
@@ -26,7 +26,7 @@
#include <unistd.h>
#include <stdlib.h>
-#include "mp_msg.h"
+#include "core/mp_msg.h"
#include "input.h"
#include "lirc.h"
diff --git a/core/m_config.c b/core/m_config.c
index 7a4d711d3f..9c0ddf8e20 100644
--- a/core/m_config.c
+++ b/core/m_config.c
@@ -31,8 +31,8 @@
#include "talloc.h"
#include "m_config.h"
-#include "m_option.h"
-#include "mp_msg.h"
+#include "core/m_option.h"
+#include "core/mp_msg.h"
#define MAX_PROFILE_DEPTH 20
diff --git a/core/m_config.h b/core/m_config.h
index 9098a23c97..de89803cac 100644
--- a/core/m_config.h
+++ b/core/m_config.h
@@ -21,7 +21,7 @@
#include <stdbool.h>
-#include "bstr.h"
+#include "core/bstr.h"
// m_config provides an API to manipulate the config variables in MPlayer.
// It makes use of the Options API to provide a context stack that
diff --git a/core/m_option.c b/core/m_option.c
index 3f300326ca..f64b4deb20 100644
--- a/core/m_option.c
+++ b/core/m_option.c
@@ -35,8 +35,8 @@
#include <libavutil/avstring.h>
#include "talloc.h"
-#include "m_option.h"
-#include "mp_msg.h"
+#include "core/m_option.h"
+#include "core/mp_msg.h"
#include "stream/url.h"
char *m_option_strerror(int code)
@@ -1116,7 +1116,7 @@ const m_option_type_t m_option_type_subconfig_struct = {
.parse = parse_subconf,
};
-#include "libmpcodecs/img_format.h"
+#include "video/img_format.h"
static int parse_imgfmt(const m_option_t *opt, struct bstr name,
struct bstr param, void *dst)
@@ -1154,7 +1154,7 @@ const m_option_type_t m_option_type_imgfmt = {
.copy = copy_opt,
};
-#include "libaf/format.h"
+#include "audio/format.h"
static int parse_afmt(const m_option_t *opt, struct bstr name,
struct bstr param, void *dst)
@@ -1308,7 +1308,7 @@ const m_option_type_t m_option_type_time_size = {
//// Objects (i.e. filters, etc) settings
-#include "m_struct.h"
+#include "core/m_struct.h"
#undef VAL
#define VAL(x) (*(m_obj_settings_t **)(x))
diff --git a/core/m_option.h b/core/m_option.h
index 75f1c709d1..30bd6a9ff2 100644
--- a/core/m_option.h
+++ b/core/m_option.h
@@ -24,7 +24,7 @@
#include <stdbool.h>
#include "config.h"
-#include "bstr.h"
+#include "core/bstr.h"
// m_option allows to parse, print and copy data of various types.
diff --git a/core/m_property.c b/core/m_property.c
index f97bb366a4..8254218d0c 100644
--- a/core/m_property.c
+++ b/core/m_property.c
@@ -30,10 +30,10 @@
#include <libavutil/common.h>
#include "talloc.h"
-#include "m_option.h"
+#include "core/m_option.h"
#include "m_property.h"
-#include "mp_msg.h"
-#include "mpcommon.h"
+#include "core/mp_msg.h"
+#include "core/mp_common.h"
const struct m_option_type m_option_type_dummy = {
.name = "Unknown",
diff --git a/core/m_struct.c b/core/m_struct.c
index 7b885cc905..2bf5f36485 100644
--- a/core/m_struct.c
+++ b/core/m_struct.c
@@ -24,9 +24,9 @@
#include <stdlib.h>
#include <string.h>
-#include "m_option.h"
-#include "m_struct.h"
-#include "mp_msg.h"
+#include "core/m_option.h"
+#include "core/m_struct.h"
+#include "core/mp_msg.h"
const m_option_t*
m_struct_get_field(const m_struct_t* st,const char* f) {
diff --git a/core/m_struct.h b/core/m_struct.h
index 1645ae734a..6ddd221f1b 100644
--- a/core/m_struct.h
+++ b/core/m_struct.h
@@ -19,7 +19,7 @@
#ifndef MPLAYER_M_STRUCT_H
#define MPLAYER_M_STRUCT_H
-#include "bstr.h"
+#include "core/bstr.h"
/// \defgroup OptionsStruct Options struct
/// \ingroup Options
diff --git a/core/mp_common.c b/core/mp_common.c
index d4811440aa..eecd0710cc 100644
--- a/core/mp_common.c
+++ b/core/mp_common.c
@@ -17,7 +17,7 @@
*/
#include "talloc.h"
-#include "mpcommon.h"
+#include "core/mp_common.h"
char *mp_format_time(double time, bool fractions)
{
diff --git a/core/mp_core.h b/core/mp_core.h
index 99ce12b033..910bfb82a4 100644
--- a/core/mp_core.h
+++ b/core/mp_core.h
@@ -21,11 +21,11 @@
#include <stdbool.h>
-#include "options.h"
-#include "mixer.h"
+#include "core/options.h"
#include "sub/subreader.h"
#include "sub/find_subfiles.h"
-#include "libmpdemux/demuxer.h"
+#include "audio/mixer.h"
+#include "demux/demux.h"
// definitions used internally by the core player code
diff --git a/core/mp_fifo.c b/core/mp_fifo.c
index 701b7a0bc3..fd8a87098e 100644
--- a/core/mp_fifo.c
+++ b/core/mp_fifo.c
@@ -24,7 +24,7 @@
#include "input/keycodes.h"
#include "mp_fifo.h"
#include "talloc.h"
-#include "options.h"
+#include "core/options.h"
struct mp_fifo {
diff --git a/core/mp_fifo.h b/core/mp_fifo.h
index 015286db83..f08cd00415 100644
--- a/core/mp_fifo.h
+++ b/core/mp_fifo.h
@@ -19,7 +19,7 @@
#ifndef MPLAYER_MP_FIFO_H
#define MPLAYER_MP_FIFO_H
-#include "bstr.h"
+#include "core/bstr.h"
struct mp_fifo;
void mplayer_put_key(struct mp_fifo *fifo, int code);
diff --git a/core/mp_msg.c b/core/mp_msg.c
index 627ee04187..d0cce8e064 100644
--- a/core/mp_msg.c
+++ b/core/mp_msg.c
@@ -31,7 +31,7 @@
#include <libintl.h>
#endif
-#include "mp_msg.h"
+#include "core/mp_msg.h"
/* maximum message length of mp_msg */
#define MSGSIZE_MAX 6144
diff --git a/core/mp_msg.h b/core/mp_msg.h
index 5f043243fa..320912dd4c 100644
--- a/core/mp_msg.h
+++ b/core/mp_msg.h
@@ -132,7 +132,7 @@ void mp_msg_init(void);
int mp_msg_test(int mod, int lev);
#include "config.h"
-#include "mpcommon.h"
+#include "core/mp_common.h"
char *mp_gtext(const char *string);
diff --git a/core/mplayer.c b/core/mplayer.c
index 7006614df1..180bb2a011 100644
--- a/core/mplayer.c
+++ b/core/mplayer.c
@@ -63,33 +63,33 @@
#include <errno.h>
-#include "mp_msg.h"
+#include "core/mp_msg.h"
#include "av_log.h"
-#include "m_option.h"
-#include "m_config.h"
-#include "mplayer.h"
-#include "m_property.h"
+#include "core/m_option.h"
+#include "core/m_config.h"
+#include "core/mplayer.h"
+#include "core/m_property.h"
#include "sub/subreader.h"
#include "sub/find_subfiles.h"
#include "sub/dec_sub.h"
-#include "mp_osd.h"
-#include "libvo/video_out.h"
-#include "screenshot.h"
+#include "core/mp_osd.h"
+#include "video/out/vo.h"
+#include "core/screenshot.h"
#include "sub/sub.h"
-#include "cpudetect.h"
+#include "core/cpudetect.h"
#ifdef CONFIG_X11
-#include "libvo/x11_common.h"
+#include "video/out/x11_common.h"
#endif
-#include "libao2/audio_out.h"
+#include "audio/out/ao.h"
-#include "codec-cfg.h"
+#include "core/codec-cfg.h"
#include "sub/spudec.h"
#include "sub/vobsub.h"
@@ -97,9 +97,9 @@
#include "osdep/getch2.h"
#include "osdep/timer.h"
-#include "input/input.h"
+#include "core/input/input.h"
-#include "encode.h"
+#include "core/encode.h"
int slave_mode = 0;
int enable_mouse_movements = 0;
@@ -119,20 +119,20 @@ char *heartbeat_cmd;
//**************************************************************************//
// Playtree
//**************************************************************************//
-#include "playlist.h"
-#include "playlist_parser.h"
+#include "core/playlist.h"
+#include "core/playlist_parser.h"
//**************************************************************************//
// Config
//**************************************************************************//
-#include "parser-cfg.h"
-#include "parser-mpcmd.h"
+#include "core/parser-cfg.h"
+#include "core/parser-mpcmd.h"
//**************************************************************************//
// Config file
//**************************************************************************//
-#include "path.h"
+#include "core/path.h"
//**************************************************************************//
//**************************************************************************//
@@ -142,24 +142,24 @@ char *heartbeat_cmd;
static int max_framesize = 0;
#include "stream/stream.h"
-#include "libmpdemux/demuxer.h"
-#include "libmpdemux/stheader.h"
+#include "demux/demux.h"
+#include "demux/stheader.h"
#ifdef CONFIG_DVDREAD
#include "stream/stream_dvd.h"
#endif
-#include "libmpcodecs/dec_audio.h"
-#include "libmpcodecs/dec_video.h"
-#include "libmpcodecs/mp_image.h"
-#include "libmpcodecs/vf.h"
-#include "libmpcodecs/vd.h"
+#include "audio/decode/dec_audio.h"
+#include "video/decode/dec_video.h"
+#include "video/mp_image.h"
+#include "video/filter/vf.h"
+#include "video/decode/vd.h"
-#include "mixer.h"
+#include "audio/mixer.h"
-#include "mp_core.h"
-#include "options.h"
-#include "defaultopts.h"
+#include "core/mp_core.h"
+#include "core/options.h"
+#include "core/defaultopts.h"
static const char help_text[] = _(
"Usage: mpv [options] [url|path/]filename\n"
@@ -200,7 +200,7 @@ static const char av_desync_help_text[] = _(
//**************************************************************************//
//**************************************************************************//
-#include "mp_fifo.h"
+#include "core/mp_fifo.h"
static int drop_frame_cnt; // total number of dropped frames
@@ -244,8 +244,8 @@ char *edl_output_filename; // file to put EDL entries in (-edlout)
int use_filedir_conf;
-#include "mpcommon.h"
-#include "command.h"
+#include "core/mp_common.h"
+#include "core/command.h"
static void reset_subtitles(struct MPContext *mpctx);
static void reinit_subs(struct MPContext *mpctx);
@@ -789,11 +789,11 @@ static void load_per_file_options(m_config_t *conf,
m_config_set_option(conf, params[n].name, params[n].value);
}
/* When libmpdemux performs a blocking operation (network connection or
* cache filling) if the operation fails we use this function to check
* if it was interrupted by the user.
* The function returns whether it was interrupted. */
-static bool libmpdemux_was_interrupted(struct MPContext *mpctx)
+static bool demux_was_interrupted(struct MPContext *mpctx)
{
for (;;) {
if (mpctx->stop_play != KEEP_PLAYING
@@ -3741,7 +3741,7 @@ static void play_current_file(struct MPContext *mpctx)
stream_filename = mpctx->resolve_result->url;
mpctx->stream = open_stream(stream_filename, opts, &mpctx->file_format);
if (!mpctx->stream) { // error...
- libmpdemux_was_interrupted(mpctx);
+ demux_was_interrupted(mpctx);
goto terminate_playback;
@@ -789,11 +789,11 @@ static void load_per_file_options(m_config_t *conf,
m_config_set_option(conf, params[n].name, params[n].value);
}
-/* When libmpdemux performs a blocking operation (network connection or
+/* When demux performs a blocking operation (network connection or
* cache filling) if the operation fails we use this function to check
* if it was interrupted by the user.